@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2020 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,10 +22,14 @@ using System.Collections.Generic;
 using System.ComponentModel;
 using System.Diagnostics;
 using System.Drawing;
+using System.Globalization;
 using System.Text;
 
+using KeePass.Resources;
 using KeePass.UI;
 
+using KeePassLib.Utility;
+
 namespace KeePass.App.Configuration
 {
 	[Flags]
@@ -67,7 +71,10 @@ namespace KeePass.App.Configuration
 		HideBuiltInPwGenPrfInEntryDlg = 0x10000,
 		ShowLastAccessTime = 0x20000,
 		HideNewDbInfoDialogs = 0x40000,
-		HideAutoTypeObfInfo = 0x80000
+		HideAutoTypeObfInfo = 0x80000,
+		NoQuickSearchClear = 0x100000,
+		SecureDesktopIme = 0x200000,
+		AdjustWeakKdfParameters = 0x400000
 	}
 
 	[Flags]
@@ -133,6 +140,8 @@ namespace KeePass.App.Configuration
 			}
 		}
 
+		// internal const float PasswordFontSizeMaximum = 12.0f; // Points
+
 		private AceFont m_fontPasswords = new AceFont(true);
 		public AceFont PasswordFont
 		{
@@ -152,19 +161,46 @@ namespace KeePass.App.Configuration
 			set { m_bForceSysFont = value; }
 		}
 
-		private BannerStyle m_bannerStyle = BannerStyle.WinVistaBlack;
+		private BannerStyle m_bannerStyle = BannerStyle.Dark;
 		public BannerStyle BannerStyle
 		{
 			get { return m_bannerStyle; }
 			set { m_bannerStyle = value; }
 		}
 
-		private bool m_bShowImportStatusDlg = false;
 		[DefaultValue(false)]
-		public bool ShowImportStatusDialog
+		public bool ShowImportStatusDialog { get; set; }
+
+		private bool m_bShowRecycleDlg = true;
+		[DefaultValue(true)]
+		public bool ShowRecycleConfirmDialog
 		{
-			get { return m_bShowImportStatusDlg; }
-			set { m_bShowImportStatusDlg = value; }
+			get { return m_bShowRecycleDlg; }
+			set { m_bShowRecycleDlg = value; }
+		}
+
+		private bool m_bShowCmdUriDlg = true;
+		[DefaultValue(true)]
+		public bool ShowCmdUriConfirmDialog
+		{
+			get { return m_bShowCmdUriDlg; }
+			set { m_bShowCmdUriDlg = value; }
+		}
+
+		private bool m_bShowCmdPlhDlg = true;
+		[DefaultValue(true)]
+		public bool ShowCmdPlhConfirmDialog
+		{
+			get { return m_bShowCmdPlhDlg; }
+			set { m_bShowCmdPlhDlg = value; }
+		}
+
+		private bool m_bShowRefPPlhDlg = true;
+		[DefaultValue(true)]
+		public bool ShowRefPPlhConfirmDialog
+		{
+			get { return m_bShowRefPPlhDlg; }
+			set { m_bShowRefPPlhDlg = value; }
 		}
 
 		private bool m_bShowDbMntncResDlg = true;
@@ -175,14 +211,6 @@ namespace KeePass.App.Configuration
 			set { m_bShowDbMntncResDlg = value; }
 		}
 
-		private bool m_bShowRecycleDlg = true;
-		[DefaultValue(true)]
-		public bool ShowRecycleConfirmDialog
-		{
-			get { return m_bShowRecycleDlg; }
-			set { m_bShowRecycleDlg = value; }
-		}
-
 		private bool m_bShowEmSheetDlg = true;
 		[DefaultValue(true)]
 		public bool ShowEmSheetDialog
@@ -191,6 +219,14 @@ namespace KeePass.App.Configuration
 			set { m_bShowEmSheetDlg = value; }
 		}
 
+		private bool m_bShowDbOpenUnkVerDlg = true;
+		[DefaultValue(true)]
+		public bool ShowDbOpenUnkVerDialog
+		{
+			get { return m_bShowDbOpenUnkVerDlg; }
+			set { m_bShowDbOpenUnkVerDlg = value; }
+		}
+
 		// private bool m_bUseCustomTsRenderer = true;
 		// [DefaultValue(true)]
 		// public bool UseCustomToolStripRenderer
@@ -211,21 +247,11 @@ namespace KeePass.App.Configuration
 			}
 		}
 
-		private bool m_bTreeViewShowLines = false;
 		[DefaultValue(false)]
-		public bool TreeViewShowLines
-		{
-			get { return m_bTreeViewShowLines; }
-			set { m_bTreeViewShowLines = value; }
-		}
+		public bool TreeViewShowLines { get; set; }
 
-		private bool m_bOptScreenReader = false;
 		[DefaultValue(false)]
-		public bool OptimizeForScreenReader
-		{
-			get { return m_bOptScreenReader; }
-			set { m_bOptScreenReader = value; }
-		}
+		public bool OptimizeForScreenReader { get; set; }
 
 		private string m_strDataViewerRect = string.Empty;
 		[DefaultValue("")]
@@ -342,13 +368,8 @@ namespace KeePass.App.Configuration
 		//	set { m_bEditCancelConfirmation = value; }
 		// }
 
-		private bool m_bAdvATCmds = false;
 		[DefaultValue(false)]
-		public bool ShowAdvAutoTypeCommands
-		{
-			get { return m_bAdvATCmds; }
-			set { m_bAdvATCmds = value; }
-		}
+		public bool ShowAdvAutoTypeCommands { get; set; }
 
 		private bool m_bSecDeskSound = true;
 		[DefaultValue(true)]
@@ -365,21 +386,11 @@ namespace KeePass.App.Configuration
 		{
 		}
 
-		private bool m_bRememberHidePwsMain = true;
-		[DefaultValue(true)]
-		public bool RememberHidingPasswordsMain
-		{
-			get { return m_bRememberHidePwsMain; }
-			set { m_bRememberHidePwsMain = value; }
-		}
-
-		private bool m_bSepHiding = false;
 		[DefaultValue(false)]
-		public bool SeparateHidingSettings
-		{
-			get { return m_bSepHiding; }
-			set { m_bSepHiding = value; }
-		}
+		public bool RememberHidingPasswordsMain { get; set; }
+
+		[DefaultValue(false)]
+		public bool SeparateHidingSettings { get; set; }
 
 		private bool m_bHideInEntryDialog = true;
 		[DefaultValue(true)]
@@ -389,13 +400,11 @@ namespace KeePass.App.Configuration
 			set { m_bHideInEntryDialog = value; }
 		}
 
-		private bool m_bUnhideBtnAlsoUnhidesSec = false;
 		[DefaultValue(false)]
-		public bool UnhideButtonAlsoUnhidesSource
-		{
-			get { return m_bUnhideBtnAlsoUnhidesSec; }
-			set { m_bUnhideBtnAlsoUnhidesSec = value; }
-		}
+		public bool UnhideButtonAlsoUnhidesSource { get; set; }
+
+		[DefaultValue(false)]
+		public bool UnhideEmptyData { get; set; }
 	}
 
 	public sealed class AceFont
@@ -429,11 +438,12 @@ namespace KeePass.App.Configuration
 			set { m_gu = value; m_bCacheValid = false; }
 		}
 
-		private FontStyle m_fStyle = FontStyle.Regular;
+		private FontStyle m_fs = FontStyle.Regular;
+		[DefaultValue(FontStyle.Regular)]
 		public FontStyle Style
 		{
-			get { return m_fStyle; }
-			set { m_fStyle = value; m_bCacheValid = false; }
+			get { return m_fs; }
+			set { m_fs = value; m_bCacheValid = false; }
 		}
 
 		private bool m_bOverrideUIDefault = false;
@@ -447,14 +457,20 @@ namespace KeePass.App.Configuration
 		{
 		}
 
-		public AceFont(Font f)
+		public AceFont(Font f) : this(f, false)
+		{
+		}
+
+		internal AceFont(Font f, bool bOverrideUIDefault)
 		{
 			if(f == null) throw new ArgumentNullException("f");
 
 			this.Family = f.FontFamily.Name;
 			m_fSize = f.Size;
-			m_fStyle = f.Style;
 			m_gu = f.Unit;
+			m_fs = f.Style;
+
+			m_bOverrideUIDefault = bOverrideUIDefault;
 		}
 
 		public AceFont(bool bMonospace)
@@ -462,13 +478,102 @@ namespace KeePass.App.Configuration
 			if(bMonospace) m_strFamily = "Courier New";
 		}
 
+		internal AceFont CloneDeep()
+		{
+			return (AceFont)MemberwiseClone();
+		}
+
+		public override string ToString()
+		{
+			StringBuilder sb = new StringBuilder();
+
+			if(string.IsNullOrEmpty(m_strFamily))
+			{
+				sb.Append('(');
+				sb.Append(KPRes.None);
+				sb.Append(')');
+			}
+			else sb.Append(m_strFamily);
+
+			sb.Append(", ");
+			sb.Append(Math.Round(m_fSize)); // 8.25, 9, 9.75, 11.25, 12, ...
+			sb.Append(' ');
+			sb.Append(GfxUtil.GraphicsUnitToString(m_gu));
+
+			string strStyle = FontUtil.FontStyleToString(m_fs);
+			if(!string.IsNullOrEmpty(strStyle))
+			{
+				sb.Append(", ");
+				sb.Append(strStyle);
+			}
+
+			return sb.ToString();
+		}
+
 		public Font ToFont()
 		{
 			if(m_bCacheValid) return m_fCached;
 
-			m_fCached = FontUtil.CreateFont(m_strFamily, m_fSize, m_fStyle, m_gu);
+			m_fCached = FontUtil.CreateFont(m_strFamily, m_fSize, m_fs, m_gu);
 			m_bCacheValid = true;
 			return m_fCached;
 		}
+
+		private static void AppendCss(StringBuilder sb, string strIndent,
+			string strProperty, params string[] vValueParts)
+		{
+			sb.Append(strIndent);
+			sb.Append(strProperty);
+			sb.Append(": ");
+
+			for(int i = 0; i < vValueParts.Length; ++i)
+				sb.Append(vValueParts[i]); // Without separator space
+
+			sb.AppendLine(";");
+		}
+
+		internal string ToCss(string strIndent, string strFamilyFallback,
+			bool bWithDefaults)
+		{
+			if(strIndent == null) { Debug.Assert(false); strIndent = string.Empty; }
+
+			StringBuilder sb = new StringBuilder();
+			NumberFormatInfo nfi = NumberFormatInfo.InvariantInfo;
+
+			string strFamily = string.Empty;
+			if(!string.IsNullOrEmpty(m_strFamily))
+				strFamily = "\"" + StrUtil.CssEscapeString(m_strFamily) + "\"";
+			else { Debug.Assert(false); }
+			if(!string.IsNullOrEmpty(strFamilyFallback))
+				strFamily += ((strFamily.Length != 0) ? ", " : string.Empty) +
+					strFamilyFallback;
+			if(strFamily.Length != 0)
+				AppendCss(sb, strIndent, "font-family", strFamily);
+
+			AppendCss(sb, strIndent, "font-size", m_fSize.ToString(nfi),
+				GfxUtil.GraphicsUnitToString(m_gu));
+
+			if((m_fs & FontStyle.Bold) != FontStyle.Regular)
+				AppendCss(sb, strIndent, "font-weight", "bold");
+			else if(bWithDefaults)
+				AppendCss(sb, strIndent, "font-weight", "normal");
+
+			if((m_fs & FontStyle.Italic) != FontStyle.Regular)
+				AppendCss(sb, strIndent, "font-style", "italic");
+			else if(bWithDefaults)
+				AppendCss(sb, strIndent, "font-style", "normal");
+
+			const FontStyle fsUS = FontStyle.Underline | FontStyle.Strikeout;
+			if((m_fs & fsUS) == fsUS)
+				AppendCss(sb, strIndent, "text-decoration", "underline line-through");
+			else if((m_fs & FontStyle.Underline) != FontStyle.Regular)
+				AppendCss(sb, strIndent, "text-decoration", "underline");
+			else if((m_fs & FontStyle.Strikeout) != FontStyle.Regular)
+				AppendCss(sb, strIndent, "text-decoration", "line-through");
+			else if(bWithDefaults)
+				AppendCss(sb, strIndent, "text-decoration", "none");
+
+			return sb.ToString();
+		}
 	}
 }
