@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -292,10 +292,12 @@ namespace KeePass.App.Configuration
 		internal void OnLoad()
 		{
 			ulong uVersion = this.Meta.GetVersion();
-			AceMainWindow aceMW = this.MainWindow;
-			AceSecurity aceSec = this.Security;
-			AceSearch aceSearch = this.Search;
+			AceApplication aceApp = this.Application;
+			AceDefaults aceDef = this.Defaults;
 			AceIntegration aceInt = this.Integration;
+			AceMainWindow aceMW = this.MainWindow;
+			AceSearch aceSearch = this.Search;
+			AceSecurity aceSec = this.Security;
 
 			// aceInt.UrlSchemeOverrides.SetDefaultsIfEmpty();
 
@@ -344,6 +346,19 @@ namespace KeePass.App.Configuration
 					aceInt.UrlSchemeOverrides.BuiltInOverridesEnabled = 0;
 			}
 
+			// When the regular configuration file contains an MRU item with a
+			// relative path and the enforced configuration file contains a
+			// corresponding one with an absolute path, the path conversion may
+			// result in duplicate MRU items;
+			// cf. GetNodeKey and MruList.AddItem (CaseIgnoreCmp)
+			aceApp.MostRecentlyUsed.Items = new List<IOConnectionInfo>(
+				MemUtil.Distinct<IOConnectionInfo, string>(aceApp.MostRecentlyUsed.Items,
+				(ioc => ioc.GetDisplayName().ToUpperInvariant()), true));
+			// Cf. GetNodeKey and AceDefaults.GetKeyAssocIndex (CaseIgnoreCmp)
+			aceDef.KeySources = new List<AceKeyAssoc>(
+				MemUtil.Distinct<AceKeyAssoc, string>(aceDef.KeySources,
+				(a => a.DatabasePath.ToUpperInvariant()), true));
+
 			if(NativeLib.IsUnix())
 			{
 				aceSec.PreventScreenCapture = false;
@@ -367,7 +382,7 @@ namespace KeePass.App.Configuration
 			if(MonoWorkarounds.IsRequired(1418))
 			{
 				aceMW.MinimizeAfterOpeningDatabase = false;
-				this.Application.Start.MinimizedAndLocked = false;
+				aceApp.Start.MinimizedAndLocked = false;
 			}
 
 			if(MonoWorkarounds.IsRequired(1976))
@@ -566,23 +581,41 @@ namespace KeePass.App.Configuration
 			fFont(ui.DataEditorFont);
 		}
 
+		public void Apply(AceApplyFlags f)
+		{
+			AceApplication aceApp = this.Application; // m_aceApp might be null
+			AceSecurity aceSec = this.Security; // m_sec might be null
+			AceIntegration aceInt = this.Integration; // m_int might be null
+
+			if((f & AceApplyFlags.Proxy) != AceApplyFlags.None)
+				IOConnection.SetProxy(aceInt.ProxyType, aceInt.ProxyAddress,
+					aceInt.ProxyPort, aceInt.ProxyAuthType, aceInt.ProxyUserName,
+					aceInt.ProxyPassword);
+
+			if((f & AceApplyFlags.Ssl) != AceApplyFlags.None)
+				IOConnection.SslCertsAcceptInvalid = aceSec.SslCertsAcceptInvalid;
+
+			if((f & AceApplyFlags.FileTransactions) != AceApplyFlags.None)
+				FileTransactionEx.ExtraSafe = aceApp.FileTxExtra;
+		}
+
 		private static readonly Dictionary<object, string> g_dictXmlPathCache =
 			new Dictionary<object, string>();
-		public static bool IsOptionEnforced(object pContainer, PropertyInfo pi)
+		public static bool IsOptionEnforced(object oContainer, PropertyInfo pi)
 		{
-			if(pContainer == null) { Debug.Assert(false); return false; }
+			if(oContainer == null) { Debug.Assert(false); return false; }
 			if(pi == null) { Debug.Assert(false); return false; }
 
 			XmlDocument xdEnforced = AppConfigSerializer.EnforcedConfigXml;
 			if(xdEnforced == null) return false;
 
 			string strObjPath;
-			if(!g_dictXmlPathCache.TryGetValue(pContainer, out strObjPath))
+			if(!g_dictXmlPathCache.TryGetValue(oContainer, out strObjPath))
 			{
-				strObjPath = XmlUtil.GetObjectXmlPath(Program.Config, pContainer);
+				strObjPath = XmlUtil.GetObjectXmlPath(Program.Config, oContainer);
 				if(string.IsNullOrEmpty(strObjPath)) { Debug.Assert(false); return false; }
 
-				g_dictXmlPathCache[pContainer] = strObjPath;
+				g_dictXmlPathCache[oContainer] = strObjPath;
 			}
 
 			string strProp = XmlSerializerEx.GetXmlName(pi);
@@ -600,18 +633,17 @@ namespace KeePass.App.Configuration
 			return XmlUtil.IsAlwaysEnforced(xn, strXPath, ctx);
 		}
 
-		public static bool IsOptionEnforced(object pContainer, string strPropertyName)
+		public static bool IsOptionEnforced(object oContainer, string strPropertyName)
 		{
-			if(pContainer == null) { Debug.Assert(false); return false; }
+			if(oContainer == null) { Debug.Assert(false); return false; }
 			if(string.IsNullOrEmpty(strPropertyName)) { Debug.Assert(false); return false; }
 
 			// To improve performance (avoid type queries), check here, too
 			XmlDocument xdEnforced = AppConfigSerializer.EnforcedConfigXml;
 			if(xdEnforced == null) return false;
 
-			Type tContainer = pContainer.GetType();
-			PropertyInfo pi = tContainer.GetProperty(strPropertyName);
-			return IsOptionEnforced(pContainer, pi);
+			PropertyInfo pi = oContainer.GetType().GetProperty(strPropertyName);
+			return IsOptionEnforced(oContainer, pi);
 		}
 
 		public static void ClearXmlPathCache()
@@ -619,24 +651,6 @@ namespace KeePass.App.Configuration
 			g_dictXmlPathCache.Clear();
 		}
 
-		public void Apply(AceApplyFlags f)
-		{
-			AceApplication aceApp = this.Application; // m_aceApp might be null
-			AceSecurity aceSec = this.Security; // m_sec might be null
-			AceIntegration aceInt = this.Integration; // m_int might be null
-
-			if((f & AceApplyFlags.Proxy) != AceApplyFlags.None)
-				IOConnection.SetProxy(aceInt.ProxyType, aceInt.ProxyAddress,
-					aceInt.ProxyPort, aceInt.ProxyAuthType, aceInt.ProxyUserName,
-					aceInt.ProxyPassword);
-
-			if((f & AceApplyFlags.Ssl) != AceApplyFlags.None)
-				IOConnection.SslCertsAcceptInvalid = aceSec.SslCertsAcceptInvalid;
-
-			if((f & AceApplyFlags.FileTransactions) != AceApplyFlags.None)
-				FileTransactionEx.ExtraSafe = aceApp.FileTxExtra;
-		}
-
 		internal static void GetNodeOptions(XmNodeOptions o, string strXPath)
 		{
 			if(o == null) { Debug.Assert(false); return; }
@@ -709,7 +723,7 @@ namespace KeePass.App.Configuration
 					break;
 
 				case "/Configuration/Application/MostRecentlyUsed/Items/ConnectionInfo":
-					strA = XmlUtil.SafeInnerXml(xn, "Path");
+					strA = XmlUtil.SafeInnerXml(xn, "Path"); // Cf. OnLoad
 					strB = XmlUtil.SafeInnerXml(xn, "UserName"); // Cf. MRU display name
 					break;
 
@@ -722,7 +736,7 @@ namespace KeePass.App.Configuration
 					break;
 
 				case "/Configuration/Defaults/KeySources/Association":
-					strA = XmlUtil.SafeInnerXml(xn, "DatabasePath");
+					strA = XmlUtil.SafeInnerXml(xn, "DatabasePath"); // Cf. OnLoad
 					break;
 
 				case "/Configuration/Integration/UrlSchemeOverrides/CustomOverrides/Override":
@@ -752,6 +766,27 @@ namespace KeePass.App.Configuration
 			return strA;
 		}
 
+		internal static T GetPropertyValue<T>(object oContainer,
+			string strPropertyName, T tDefault, out PropertyInfo piForSet)
+		{
+			piForSet = null;
+			if(oContainer == null) { Debug.Assert(false); return tDefault; }
+			if(string.IsNullOrEmpty(strPropertyName)) { Debug.Assert(false); return tDefault; }
+
+			piForSet = oContainer.GetType().GetProperty(strPropertyName);
+			if(piForSet == null) { Debug.Assert(false); return tDefault; }
+			if(piForSet.PropertyType != typeof(T))
+			{
+				Debug.Assert(false);
+				piForSet = null;
+				return tDefault;
+			}
+
+			T t = (T)piForSet.GetValue(oContainer, null);
+			if(IsOptionEnforced(oContainer, piForSet)) piForSet = null;
+			return t;
+		}
+
 		internal static string GetEmptyXml()
 		{
 			return ("<?xml version=\"1.0\" encoding=\"utf-8\"?>\r\n" +
@@ -761,9 +796,7 @@ namespace KeePass.App.Configuration
 
 		internal static XmlDocument CreateEmptyXmlDocument()
 		{
-			XmlDocument xd = XmlUtilEx.CreateXmlDocument();
-			xd.LoadXml(GetEmptyXml());
-			return xd;
+			return XmlUtilEx.LoadXmlDocumentFromString(GetEmptyXml());
 		}
 	}
 
