@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,8 +56,8 @@ namespace KeePassLib.Cryptography.Cipher
 		{
 			get
 			{
-				return ("ChaCha20 (" + KLRes.KeyBits.Replace(@"{PARAM}",
-					"256") + ", RFC 7539)");
+				return ("ChaCha20 (" + KLRes.KeyBits.Replace("{PARAM}",
+					"256") + ", RFC 8439)");
 			}
 		}
 
@@ -135,7 +135,7 @@ namespace KeePassLib.Cryptography.Cipher
 					m_c.Dispose();
 					m_c = null;
 
-					m_sBase.Close();
+					m_sBase.Dispose();
 					m_sBase = null;
 				}
 
