@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,12 +30,8 @@ namespace KeePassLib.Cryptography.Cipher
 {
 	public sealed class Salsa20Cipher : CtrBlockCipher
 	{
-		private uint[] m_s = new uint[16]; // State
-		private uint[] m_x = new uint[16]; // Working buffer
-
-		private static readonly uint[] g_sigma = new uint[4] {
-			0x61707865, 0x3320646E, 0x79622D32, 0x6B206574
-		};
+		private readonly uint[] m_s = new uint[16]; // State
+		private readonly uint[] m_x = new uint[16]; // Working buffer
 
 		public override int BlockSize
 		{
@@ -49,7 +45,11 @@ namespace KeePassLib.Cryptography.Cipher
 			if(pbIV8 == null) throw new ArgumentNullException("pbIV8");
 			if(pbIV8.Length != 8) throw new ArgumentOutOfRangeException("pbIV8");
 
-			// Key setup
+			m_s[0] = 0x61707865;
+			m_s[5] = 0x3320646E;
+			m_s[10] = 0x79622D32;
+			m_s[15] = 0x6B206574;
+
 			m_s[1] = MemUtil.BytesToUInt32(pbKey32, 0);
 			m_s[2] = MemUtil.BytesToUInt32(pbKey32, 4);
 			m_s[3] = MemUtil.BytesToUInt32(pbKey32, 8);
@@ -58,12 +58,7 @@ namespace KeePassLib.Cryptography.Cipher
 			m_s[12] = MemUtil.BytesToUInt32(pbKey32, 20);
 			m_s[13] = MemUtil.BytesToUInt32(pbKey32, 24);
 			m_s[14] = MemUtil.BytesToUInt32(pbKey32, 28);
-			m_s[0] = g_sigma[0];
-			m_s[5] = g_sigma[1];
-			m_s[10] = g_sigma[2];
-			m_s[15] = g_sigma[3];
 
-			// IV setup
 			m_s[6] = MemUtil.BytesToUInt32(pbIV8, 0);
 			m_s[7] = MemUtil.BytesToUInt32(pbIV8, 4);
 			m_s[8] = 0; // Counter, low
@@ -81,10 +76,10 @@ namespace KeePassLib.Cryptography.Cipher
 			base.Dispose(bDisposing);
 		}
 
-		protected override void NextBlock(byte[] pBlock)
+		protected override void NextBlock(byte[] pbBlock)
 		{
-			if(pBlock == null) throw new ArgumentNullException("pBlock");
-			if(pBlock.Length != 64) throw new ArgumentOutOfRangeException("pBlock");
+			if(pbBlock == null) throw new ArgumentNullException("pbBlock");
+			if(pbBlock.Length != 64) throw new ArgumentOutOfRangeException("pbBlock");
 
 			// x is a local alias for the working buffer; with this,
 			// the compiler/runtime might remove some checks
@@ -151,10 +146,10 @@ namespace KeePassLib.Cryptography.Cipher
 					int i4 = i << 2;
 					uint xi = x[i];
 
-					pBlock[i4] = (byte)xi;
-					pBlock[i4 + 1] = (byte)(xi >> 8);
-					pBlock[i4 + 2] = (byte)(xi >> 16);
-					pBlock[i4 + 3] = (byte)(xi >> 24);
+					pbBlock[i4] = (byte)xi;
+					pbBlock[i4 + 1] = (byte)(xi >> 8);
+					pbBlock[i4 + 2] = (byte)(xi >> 16);
+					pbBlock[i4 + 3] = (byte)(xi >> 24);
 				}
 
 				++s[8];
