@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -169,9 +169,10 @@ namespace KeePass.DataExchange
 
 				if(bFileReq) bExistedAlready = IOConnection.FileExists(iocOutput);
 
-				Stream s = (bFileReq ? IOConnection.OpenWrite(iocOutput) : null);
-				try { bResult = fileFormat.Export(pwExportInfo, s, slLogger); }
-				finally { if(s != null) s.Close(); }
+				using(Stream s = (bFileReq ? IOConnection.OpenWrite(iocOutput) : null))
+				{
+					bResult = fileFormat.Export(pwExportInfo, s, slLogger);
+				}
 
 				if(bFileReq && bResult)
 				{
