@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,14 +44,12 @@ namespace KeePass.DataExchange.Formats
 
 		public override bool ImportAppendsToRootGroupOnly { get { return true; } }
 
-		public override void Import(PwDatabase pwStorage, Stream sInput,
+		public override void Import(PwDatabase pdStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
-			StreamReader sr = new StreamReader(sInput, StrUtil.Utf8, true);
-			string strData = sr.ReadToEnd();
-			sr.Close();
+			string strData = MemUtil.ReadString(sInput, StrUtil.Utf8);
 
-			PwGroup pg = pwStorage.RootGroup;
+			PwGroup pg = pdStorage.RootGroup;
 			const string strSep = ": "; // Both ": " and " : " are used
 
 			strData = StrUtil.NormalizeNewLines(strData, false);
@@ -92,16 +90,12 @@ namespace KeePass.DataExchange.Formats
 						strValue = strLine; // Restore
 					else
 					{
-						strName = ImportUtil.MapNameToStandardField(strCurName, true);
+						strName = ImportUtil.MapName(strCurName, true);
 						if(string.IsNullOrEmpty(strName))
 						{
-							strName = strCurName;
-							if(string.IsNullOrEmpty(strName))
-							{
-								Debug.Assert(false);
-								strName = PwDefs.NotesField;
-								strValue = strLine; // Restore
-							}
+							Debug.Assert(false);
+							strName = PwDefs.NotesField;
+							strValue = strLine; // Restore
 						}
 					}
 				}
@@ -111,7 +105,7 @@ namespace KeePass.DataExchange.Formats
 					strValue = strValue.Trim();
 
 					if(strValue.Length != 0)
-						ImportUtil.AppendToField(pe, strName, strValue, pwStorage);
+						ImportUtil.AppendToField(pe, strName, strValue, pdStorage);
 					else if(strName == PwDefs.NotesField)
 					{
 						ProtectedString ps = pe.Strings.GetSafe(strName);
