@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -49,13 +49,13 @@ namespace KeePass.DataExchange.Formats
 			get { return KeePass.Properties.Resources.B16x16_Wizard; }
 		}
 
-		public override void Import(PwDatabase pwStorage, Stream sInput,
+		public override void Import(PwDatabase pdStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
 			byte[] pb = MemUtil.Read(sInput);
 
 			CsvImportForm dlg = new CsvImportForm();
-			dlg.InitEx(pwStorage, pb);
+			dlg.InitEx(pdStorage, pb);
 			UIUtil.ShowDialogAndDestroy(dlg);
 		}
 	}
