@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 using System;
 using System.Collections.Generic;
-using System.Diagnostics;
 using System.IO;
 using System.Text;
 
@@ -43,12 +42,10 @@ namespace KeePass.DataExchange.Formats
 
 		public override bool ImportAppendsToRootGroupOnly { get { return false; } }
 
-		public override void Import(PwDatabase pwStorage, Stream sInput,
+		public override void Import(PwDatabase pdStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
-			StreamReader sr = new StreamReader(sInput, StrUtil.Utf8, true);
-			string strData = sr.ReadToEnd();
-			sr.Close();
+			string strData = MemUtil.ReadString(sInput, StrUtil.Utf8);
 
 			// The Chrome extension of LastPass 4.1.35 encodes some
 			// special characters as XML entities; the web version and
@@ -61,7 +58,7 @@ namespace KeePass.DataExchange.Formats
 			opt.BackslashIsEscape = false;
 
 			CsvStreamReaderEx csr = new CsvStreamReaderEx(strData, opt);
-			ImportCsv(csr, pwStorage);
+			ImportCsv(csr, pdStorage);
 		}
 
 		private static void ImportCsv(CsvStreamReaderEx csr, PwDatabase pd)
@@ -76,15 +73,15 @@ namespace KeePass.DataExchange.Formats
 				return str.Equals("http://sn", StrUtil.CaseIgnoreCmp);
 			};
 
-			ctr.SetDataAppend("name", PwDefs.TitleField);
-			ctr.SetDataAppend("username", PwDefs.UserNameField);
-			ctr.SetDataAppend("password", PwDefs.PasswordField);
+			ctr.SetDataAdd("name", PwDefs.TitleField);
+			ctr.SetDataAdd("username", PwDefs.UserNameField);
+			ctr.SetDataAdd("password", PwDefs.PasswordField);
 
 			ctr.SetDataHandler(strColUrl, delegate(string str, PwEntry pe,
 				string[] vContextRow)
 			{
 				if(!fIsSecNote(vContextRow))
-					ImportUtil.AppendToField(pe, PwDefs.UrlField, str, pd);
+					ImportUtil.Add(pe, PwDefs.UrlField, str, pd);
 			});
 
 			ctr.SetDataHandler("extra", delegate(string str, PwEntry pe,
@@ -97,7 +94,7 @@ namespace KeePass.DataExchange.Formats
 					return;
 				}
 
-				ImportUtil.AppendToField(pe, PwDefs.NotesField, str, pd);
+				ImportUtil.Add(pe, PwDefs.NotesField, str, pd);
 			});
 
 			ctr.SetDataHandler("grouping", delegate(string str, PwEntry pe,
@@ -134,8 +131,7 @@ namespace KeePass.DataExchange.Formats
 				if((iFieldLen > 0) && !bNotesFound)
 				{
 					string strRaw = strLine.Substring(0, iFieldLen).Trim();
-					string strField = ImportUtil.MapNameToStandardField(strRaw, false);
-					if(string.IsNullOrEmpty(strField)) strField = strRaw;
+					string strField = ImportUtil.MapName(strRaw, false);
 
 					if(strField.Length != 0)
 					{
@@ -146,8 +142,7 @@ namespace KeePass.DataExchange.Formats
 					}
 				}
 
-				ImportUtil.AppendToField(pe, strFieldName, strLine.Substring(
-					iDataOffset), pd);
+				ImportUtil.Add(pe, strFieldName, strLine.Substring(iDataOffset), pd);
 			}
 		}
 	}
