@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2020 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 using System;
 using System.Collections.Generic;
 using System.Diagnostics;
-using System.Drawing;
 using System.IO;
 using System.Text;
 using System.Xml;
@@ -30,13 +29,12 @@ using KeePass.Util;
 
 using KeePassLib;
 using KeePassLib.Interfaces;
-using KeePassLib.Resources;
 using KeePassLib.Security;
 using KeePassLib.Utility;
 
 namespace KeePass.DataExchange.Formats
 {
-	// 1.0.2.41
+	// 1.0.2.41-1.0.2.44+
 	internal sealed class NPasswordNpw102 : FileFormatProvider
 	{
 		private const string ElemGroup = "folder";
@@ -60,9 +58,9 @@ namespace KeePass.DataExchange.Formats
 
 		private const string ElemUnsupp0 = "settings";
 
-		private static readonly string Password2Key = PwDefs.PasswordField + " 2";
+		private const string Password2Key = PwDefs.PasswordField + " 2";
 
-		private static Dictionary<string, string> m_dAutoTypeConv = null;
+		private static Dictionary<string, string> g_dAutoTypeConv = null;
 
 		public override bool SupportsImport { get { return true; } }
 		public override bool SupportsExport { get { return false; } }
@@ -71,66 +69,48 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "npw"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_NPassword; }
-		}
-
-		public override void Import(PwDatabase pwStorage, Stream sInput,
+		public override void Import(PwDatabase pdStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
-			if(m_dAutoTypeConv == null)
-			{
-				Dictionary<string, string> d = new Dictionary<string, string>();
-
-				d[@"{login}"] = @"{USERNAME}";
-				d[@"{password}"] = @"{PASSWORD}";
-				d[@"{additional key}"] = @"{S:" + Password2Key + @"}";
-				d[@"{url}"] = @"{URL}";
-				d[@"{memo}"] = @"{NOTES}";
-				d[@"[tab]"] = @"{TAB}";
-				d[@"[enter]"] = @"{ENTER}";
-
-				m_dAutoTypeConv = d;
-			}
+			if(g_dAutoTypeConv == null)
+				g_dAutoTypeConv = new Dictionary<string, string>
+				{
+					{ @"{login}", @"{USERNAME}" },
+					{ @"{password}", @"{PASSWORD}" },
+					{ @"{additional key}", @"{S:" + Password2Key + @"}" },
+					{ @"{url}", @"{URL}" },
+					{ @"{memo}", @"{NOTES}" },
+					{ @"[tab]", @"{TAB}" },
+					{ @"[enter]", @"{ENTER}" }
+				};
 
 			byte[] pbData = MemUtil.Read(sInput);
 
-			string strFmt = KLRes.FileLoadFailed + MessageService.NewParagraph +
-				KPRes.NoEncNoCompress;
-			// The file must start with "<?xml"
+			// nPassword has options for encrypting/compressing exports,
+			// which are unsupported; the file must start with "<?xml"
 			if((pbData.Length < 6) || (pbData[0] != 0x3C) || (pbData[1] != 0x3F) ||
 				(pbData[2] != 0x78) || (pbData[3] != 0x6D) || (pbData[4] != 0x6C))
-				throw new FormatException(strFmt);
+				throw new FormatException(KPRes.NoEncNoCompress);
 
 			string strData = Encoding.Default.GetString(pbData);
 			strData = strData.Replace(@"&", @"&amp;");
 
-			byte[] pbDataUtf8 = StrUtil.Utf8.GetBytes(strData);
-
-			XmlDocument xmlDoc = XmlUtilEx.CreateXmlDocument();
-			using(MemoryStream ms = new MemoryStream(pbDataUtf8, false))
-			{
-				using(StreamReader sr = new StreamReader(ms, StrUtil.Utf8))
-				{
-					xmlDoc.Load(sr);
-				}
-			}
+			XmlDocument xmlDoc = XmlUtilEx.LoadXmlDocumentFromString(strData);
 
 			XmlNode xmlRoot = xmlDoc.DocumentElement;
 
 			foreach(XmlNode xmlChild in xmlRoot.ChildNodes)
 			{
 				if(xmlChild.Name == ElemGroup)
-					ReadGroup(xmlChild, pwStorage.RootGroup, pwStorage);
+					ReadGroup(xmlChild, pdStorage.RootGroup, pdStorage);
 				else if(xmlChild.Name == ElemEntry)
-					ReadEntry(xmlChild, pwStorage.RootGroup, pwStorage);
+					ReadEntry(xmlChild, pdStorage.RootGroup, pdStorage);
 				else if(xmlChild.Name == ElemUnsupp0) { }
 				else { Debug.Assert(false); }
 			}
 		}
 
-		private static void ReadGroup(XmlNode xmlNode, PwGroup pgParent, PwDatabase pwStorage)
+		private static void ReadGroup(XmlNode xmlNode, PwGroup pgParent, PwDatabase pd)
 		{
 			PwGroup pg = new PwGroup(true, true);
 			pgParent.AddGroup(pg, true);
@@ -147,15 +127,16 @@ namespace KeePass.DataExchange.Formats
 					}
 				}
 				else if(xmlChild.Name == ElemGroup)
-					ReadGroup(xmlChild, pg, pwStorage);
+					ReadGroup(xmlChild, pg, pd);
 				else if(xmlChild.Name == ElemEntry)
-					ReadEntry(xmlChild, pg, pwStorage);
-				else if(xmlChild.Name == ElemTags) { }
+					ReadEntry(xmlChild, pg, pd);
+				else if(xmlChild.Name == ElemTags)
+					AddTags(pg.Tags, XmlUtil.SafeInnerText(xmlChild));
 				else { Debug.Assert(false); }
 			}
 		}
 
-		private static void ReadEntry(XmlNode xmlNode, PwGroup pgParent, PwDatabase pwStorage)
+		private static void ReadEntry(XmlNode xmlNode, PwGroup pgParent, PwDatabase pd)
 		{
 			PwEntry pe = new PwEntry(true, true);
 			pgParent.AddEntry(pe, true);
@@ -168,31 +149,23 @@ namespace KeePass.DataExchange.Formats
 
 				if(xmlChild.NodeType == XmlNodeType.Text)
 					ImportUtil.AppendToField(pe, PwDefs.TitleField, (xmlChild.Value ??
-						string.Empty).Trim(), pwStorage, " ", false);
+						string.Empty).Trim(), pd, " ", false);
 				else if(xmlChild.Name == ElemEntryUser)
-					pe.Strings.Set(PwDefs.UserNameField, new ProtectedString(
-						pwStorage.MemoryProtection.ProtectUserName, strValue));
+					ImportUtil.Add(pe, PwDefs.UserNameField, strValue, pd);
 				else if(xmlChild.Name == ElemEntryPassword)
-					pe.Strings.Set(PwDefs.PasswordField, new ProtectedString(
-						pwStorage.MemoryProtection.ProtectPassword, strValue));
+					ImportUtil.Add(pe, PwDefs.PasswordField, strValue, pd);
 				else if(xmlChild.Name == ElemEntryPassword2)
 				{
 					if(strValue.Length > 0) // Prevent empty item
 						pe.Strings.Set(Password2Key, new ProtectedString(
-							pwStorage.MemoryProtection.ProtectPassword, strValue));
+							pd.MemoryProtection.ProtectPassword, strValue));
 				}
 				else if(xmlChild.Name == ElemEntryUrl)
-					pe.Strings.Set(PwDefs.UrlField, new ProtectedString(
-						pwStorage.MemoryProtection.ProtectUrl, strValue));
+					ImportUtil.Add(pe, PwDefs.UrlField, strValue, pd);
 				else if(xmlChild.Name == ElemEntryNotes)
-					pe.Strings.Set(PwDefs.NotesField, new ProtectedString(
-						pwStorage.MemoryProtection.ProtectNotes, strValue));
+					ImportUtil.Add(pe, PwDefs.NotesField, strValue, pd);
 				else if(xmlChild.Name == ElemTags)
-				{
-					string strTags = strValue.Replace(' ', ';');
-					List<string> vTags = StrUtil.StringToTags(strTags);
-					foreach(string strTag in vTags) { pe.AddTag(strTag); }
-				}
+					AddTags(pe.Tags, strValue);
 				else if(xmlChild.Name == ElemEntryExpires)
 					pe.Expires = StrUtil.StringToBool(strValue);
 				else if(xmlChild.Name == ElemEntryExpiryTime)
@@ -224,7 +197,7 @@ namespace KeePass.DataExchange.Formats
 					string strValue = XmlUtil.SafeInnerText(xmlChild);
 
 					string strConv = null;
-					foreach(KeyValuePair<string, string> kvp in m_dAutoTypeConv)
+					foreach(KeyValuePair<string, string> kvp in g_dAutoTypeConv)
 					{
 						if(kvp.Key.Equals(strValue, StrUtil.CaseIgnoreCmp))
 						{
@@ -241,5 +214,13 @@ namespace KeePass.DataExchange.Formats
 
 			pe.AutoType.DefaultSequence = strSeq;
 		}
+
+		private static void AddTags(List<string> lTags, string strNewTags)
+		{
+			if(string.IsNullOrEmpty(strNewTags)) return;
+
+			StrUtil.AddTags(lTags, StrUtil.StringToTags(
+				strNewTags.Replace(' ', ';')));
+		}
 	}
 }
