@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,17 +19,13 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
 using System.IO;
-using System.Diagnostics;
-using System.Globalization;
-using System.Drawing;
+using System.Text;
 
 using KeePass.Resources;
 
 using KeePassLib;
 using KeePassLib.Interfaces;
-using KeePassLib.Security;
 using KeePassLib.Utility;
 
 namespace KeePass.DataExchange.Formats
@@ -44,17 +40,10 @@ namespace KeePass.DataExchange.Formats
 		public override string DefaultExtension { get { return "csv"; } }
 		public override string ApplicationGroup { get { return KPRes.PasswordManagers; } }
 
-		public override Image SmallIcon
-		{
-			get { return KeePass.Properties.Resources.B16x16_Imp_NortonIdSafe; }
-		}
-
-		public override void Import(PwDatabase pwStorage, Stream sInput,
+		public override void Import(PwDatabase pdStorage, Stream sInput,
 			IStatusLogger slLogger)
 		{
-			StreamReader sr = new StreamReader(sInput, Encoding.Unicode, true);
-			string strData = sr.ReadToEnd();
-			sr.Close();
+			string strData = MemUtil.ReadString(sInput, Encoding.Unicode);
 
 			CsvOptions opt = new CsvOptions();
 			opt.BackslashIsEscape = false;
@@ -72,7 +61,7 @@ namespace KeePass.DataExchange.Formats
 					v[2].Equals("password", StrUtil.CaseIgnoreCmp))
 					continue; // Header
 
-				PwGroup pg = pwStorage.RootGroup;
+				PwGroup pg = pdStorage.RootGroup;
 				string strGroup = v[4];
 				if(!string.IsNullOrEmpty(strGroup))
 					pg = pg.FindCreateGroup(strGroup, true);
@@ -80,10 +69,10 @@ namespace KeePass.DataExchange.Formats
 				PwEntry pe = new PwEntry(true, true);
 				pg.AddEntry(pe, true);
 
-				ImportUtil.AppendToField(pe, PwDefs.UrlField, v[0], pwStorage);
-				ImportUtil.AppendToField(pe, PwDefs.UserNameField, v[1], pwStorage);
-				ImportUtil.AppendToField(pe, PwDefs.PasswordField, v[2], pwStorage);
-				ImportUtil.AppendToField(pe, PwDefs.TitleField, v[3], pwStorage);
+				ImportUtil.Add(pe, PwDefs.UrlField, v[0], pdStorage);
+				ImportUtil.Add(pe, PwDefs.UserNameField, v[1], pdStorage);
+				ImportUtil.Add(pe, PwDefs.PasswordField, v[2], pdStorage);
+				ImportUtil.Add(pe, PwDefs.TitleField, v[3], pdStorage);
 			}
 		}
 	}
