@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -384,7 +384,7 @@ namespace KeePass.Ecas
 				{
 					if(dxType == EcasTypeDxMode.Selection)
 					{
-						if(o.Type.Equals(PwUuid.Zero))
+						if(o.Type.IsZero)
 							cmbTypes.SelectedIndex = 0;
 						else
 						{
