@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -358,7 +358,7 @@ namespace KeePass.Forms
 			else
 			{
 				Debug.Assert(false);
-				if(!PwUuid.Zero.Equals(m_pwDatabase.RecycleBinUuid))
+				if(!m_pwDatabase.RecycleBinUuid.IsZero)
 				{
 					m_pwDatabase.RecycleBinUuid = PwUuid.Zero;
 					m_pwDatabase.RecycleBinChanged = DateTime.UtcNow;
@@ -377,7 +377,7 @@ namespace KeePass.Forms
 			else
 			{
 				Debug.Assert(false);
-				if(!PwUuid.Zero.Equals(m_pwDatabase.EntryTemplatesGroup))
+				if(!m_pwDatabase.EntryTemplatesGroup.IsZero)
 				{
 					m_pwDatabase.EntryTemplatesGroup = PwUuid.Zero;
 					m_pwDatabase.EntryTemplatesGroupChanged = DateTime.UtcNow;
