@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -947,7 +947,7 @@ namespace KeePass.Forms
 
 			Image img = null;
 			PwDatabase pd = p.Database;
-			if((ci != null) && !ci.Equals(PwUuid.Zero) && (pd != null))
+			if((ci != null) && !ci.IsZero && (pd != null))
 			{
 				int cix = pd.GetCustomIconIndex(ci);
 				if(cix >= 0)
