@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ namespace KeePassLib.Keys
 	/// </summary>
 	public sealed class KcpUserAccount : IUserKey
 	{
-		private ProtectedBinary m_pbKeyData = null;
+		private readonly ProtectedBinary m_pbKeyData;
 
 		// Constant initialization vector (unique for KeePass)
 		private static readonly byte[] m_pbEntropy = new byte[] {
