@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,20 +56,20 @@ namespace KeePassLib
 		/// e.g. 2.19 = 0x02130000.
 		/// It is highly recommended to use <c>FileVersion64</c> instead.
 		/// </summary>
-		public static readonly uint Version32 = 0x022F0000;
+		public static readonly uint Version32 = 0x023A0000;
 
 		/// <summary>
 		/// Version, encoded as 64-bit unsigned integer
 		/// (component-wise, 16 bits per component).
 		/// </summary>
-		public static readonly ulong FileVersion64 = 0x0002002F00000000UL;
+		public static readonly ulong FileVersion64 = 0x0002003A00000000UL;
 
 		/// <summary>
 		/// Version, encoded as string.
 		/// </summary>
-		public static readonly string VersionString = "2.47";
+		public static readonly string VersionString = "2.58";
 
-		public static readonly string Copyright = @"Copyright © 2003-2021 Dominik Reichl";
+		public static readonly string Copyright = @"Copyright © 2003-2025 Dominik Reichl";
 
 		/// <summary>
 		/// Product website URL. Terminated by a forward slash.
@@ -113,7 +113,7 @@ namespace KeePassLib
 		/// Default number of master key encryption/transformation rounds
 		/// (making dictionary attacks harder).
 		/// </summary>
-		public static readonly ulong DefaultKeyEncryptionRounds = 60000;
+		public static readonly ulong DefaultKeyEncryptionRounds = 600000;
 
 		/// <summary>
 		/// Default identifier string for the title field.
@@ -190,36 +190,37 @@ namespace KeePassLib
 
 		internal const uint QualityBitsWeak = 79;
 
+		internal const string FavoriteTag = "Favorite";
+
+		internal static bool DebugMode { get; set; } // Command line option '-debug'
+
 		/// <summary>
-		/// Check if a name is a standard field name.
+		/// Check whether a name is a standard field name.
 		/// </summary>
-		/// <param name="strFieldName">Input field name.</param>
-		/// <returns>Returns <c>true</c>, if the field name is a standard
-		/// field name (title, user name, password, ...), otherwise <c>false</c>.</returns>
 		public static bool IsStandardField(string strFieldName)
 		{
-			Debug.Assert(strFieldName != null); if(strFieldName == null) return false;
+			if(strFieldName == null) { Debug.Assert(false); return false; }
 
-			if(strFieldName.Equals(TitleField)) return true;
-			if(strFieldName.Equals(UserNameField)) return true;
-			if(strFieldName.Equals(PasswordField)) return true;
-			if(strFieldName.Equals(UrlField)) return true;
-			if(strFieldName.Equals(NotesField)) return true;
-
-			return false;
+			return ((strFieldName == TitleField) ||
+				(strFieldName == UserNameField) ||
+				(strFieldName == PasswordField) ||
+				(strFieldName == UrlField) ||
+				(strFieldName == NotesField));
 		}
 
 		public static List<string> GetStandardFields()
 		{
-			List<string> l = new List<string>();
+			return new List<string>
+			{
+				TitleField, UserNameField, PasswordField, UrlField, NotesField
+			};
+		}
 
-			l.Add(TitleField);
-			l.Add(UserNameField);
-			l.Add(PasswordField);
-			l.Add(UrlField);
-			l.Add(NotesField);
+		internal static bool IsMultiLineField(string strFieldName)
+		{
+			if(strFieldName == null) { Debug.Assert(false); return false; }
 
-			return l;
+			return ((strFieldName == NotesField) || !IsStandardField(strFieldName));
 		}
 
 		/// <summary>
@@ -229,15 +230,18 @@ namespace KeePassLib
 		{
 			if(pe == null) { Debug.Assert(false); return false; }
 
-			return (pe.Strings.ReadSafe(PwDefs.TitleField) == TanTitle);
+			return (pe.Strings.ReadSafe(TitleField) == TanTitle);
 		}
 
 		internal static string GetTranslationDisplayVersion(string strFileVersion)
 		{
 			if(strFileVersion == null) { Debug.Assert(false); return string.Empty; }
 
-			if(strFileVersion == "2.39") return "2.39 / 2.39.1";
-			if(strFileVersion == "2.42") return "2.42 / 2.42.1";
+			if(strFileVersion == "2.39") return "2.39.1 / 2.39";
+			if(strFileVersion == "2.42") return "2.42.1 / 2.42";
+			if(strFileVersion == "2.48") return "2.48.1 / 2.48";
+			if(strFileVersion == "2.51") return "2.51.1 / 2.51";
+			// if(strFileVersion == "2.57") return "2.57.1 / 2.57";
 
 			return strFileVersion;
 		}
@@ -266,7 +270,6 @@ namespace KeePassLib
 		}
 	}
 
-	// #pragma warning disable 1591 // Missing XML comments warning
 	/// <summary>
 	/// Search parameters for group and entry searches.
 	/// </summary>
@@ -504,9 +507,7 @@ namespace KeePassLib
 			return (SearchParameters)this.MemberwiseClone();
 		}
 	}
-	// #pragma warning restore 1591 // Missing XML comments warning
 
-	// #pragma warning disable 1591 // Missing XML comments warning
 	/// <summary>
 	/// Memory protection configuration structure (for default fields).
 	/// </summary>
@@ -536,7 +537,6 @@ namespace KeePassLib
 			return false;
 		}
 	}
-	// #pragma warning restore 1591 // Missing XML comments warning
 
 	public sealed class ObjectTouchedEventArgs : EventArgs
 	{
