@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -88,6 +88,12 @@ namespace KeePass.Resources
 			get { return string.Empty; } // "HMAC-Based OTP"
 		}
 
+		[Obsolete]
+		public static string InvalidUserPassword
+		{
+			get { return (KPRes.Invalid + " (" + KPRes.UserName + " / " + KPRes.Password + ")!"); }
+		}
+
 		[Obsolete]
 		public static string NewDatabaseFileName
 		{
@@ -135,5 +141,23 @@ namespace KeePass.Resources
 		{
 			get { return KLRes.UnknownError; }
 		}
+
+		[Obsolete]
+		public static string UserNamePrompt
+		{
+			get { return (KPRes.UserNameStc + ":"); }
+		}
+
+		[Obsolete]
+		public static string WebSiteLogin
+		{
+			get { return "Web Site Login"; }
+		}
+
+		[Obsolete]
+		public static string WebSites
+		{
+			get { return "Web Sites"; }
+		}
 	}
 }
