@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2021 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,15 +19,16 @@
 
 using System;
 using System.Collections.Generic;
-using System.Text;
-using System.Windows.Forms;
-using System.Threading;
 using System.Diagnostics;
+using System.Text;
+using System.Threading;
+using System.Windows.Forms;
 
 using KeePass.Forms;
 using KeePass.Util.Spr;
 
 using KeePassLib;
+using KeePassLib.Utility;
 
 namespace KeePass.UI
 {
@@ -70,7 +71,7 @@ namespace KeePass.UI
 			get { return m_objListEditSync; }
 		}
 
-		private Dictionary<long, bool> m_dValidIDs = new Dictionary<long, bool>();
+		private readonly Dictionary<long, bool> m_dValidIDs = new Dictionary<long, bool>();
 		private readonly object m_objValidIDsSync = new object();
 
 		private sealed class LviUpdInfo
@@ -243,24 +244,27 @@ namespace KeePass.UI
 
 		internal static string SprCompileFn(string strText, PwListItem li)
 		{
-			string strCmp = null;
-			while(strCmp == null)
+			if(string.IsNullOrEmpty(strText)) return string.Empty;
+
+			string str = null;
+			while(str == null)
 			{
 				try
 				{
-					strCmp = SprEngine.Compile(strText, MainForm.GetEntryListSprContext(
-						li.Entry, Program.MainForm.DocumentManager.SafeFindContainerOf(
-						li.Entry)));
+					SprContext ctx = MainForm.GetEntryListSprContext(li.Entry,
+						Program.MainForm.DocumentManager.SafeFindContainerOf(
+						li.Entry));
+					str = SprEngine.Compile(strText, ctx);
 				}
 				catch(InvalidOperationException) { } // Probably collection changed
 				catch(NullReferenceException) { } // Objects disposed already
 				catch(Exception) { Debug.Assert(false); }
 			}
 
-			if(strCmp == strText) return strText;
+			if(Program.Config.MainWindow.EntryListShowDerefDataAndRefs && (str != strText))
+				str += " - " + strText;
 
-			return (Program.Config.MainWindow.EntryListShowDerefDataAndRefs ?
-				(strCmp + " - " + strText) : strCmp);
+			return StrUtil.MultiToSingleLine(str);
 		}
 	}
 }
