@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -80,7 +80,7 @@ namespace KeePassLib.Utility
 		{
 			if(m_swOut == null) return;
 
-			m_swOut.Close();
+			m_swOut.Dispose();
 			m_swOut = null;
 		}
 
