@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2024 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2025 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@ using KeePassLibSD;
 using System.IO.Compression;
 #endif
 
+using KeePassLib.Delegates;
+
 namespace KeePassLib.Utility
 {
 	/// <summary>
@@ -472,6 +474,26 @@ namespace KeePassLib.Utility
 			return ((u >> nBits) | (u << (64 - nBits)));
 		}
 
+		private static void AddVersionComponent(ref ulong uVersion, int iValue)
+		{
+			if(iValue < 0) iValue = 0;
+			else if(iValue > 0xFFFF) { Debug.Assert(false); iValue = 0xFFFF; }
+
+			uVersion = (uVersion << 16) | (uint)iValue;
+		}
+
+		internal static ulong VersionToUInt64(Version v)
+		{
+			if(v == null) { Debug.Assert(false); return 0; }
+
+			ulong u = 0;
+			AddVersionComponent(ref u, v.Major);
+			AddVersionComponent(ref u, v.Minor);
+			AddVersionComponent(ref u, v.Build);
+			AddVersionComponent(ref u, v.Revision);
+			return u;
+		}
+
 		public static bool ArraysEqual(byte[] x, byte[] y)
 		{
 			// Return false if one of them is null (not comparable)!
@@ -616,14 +638,11 @@ namespace KeePassLib.Utility
 		{
 			if(s == null) throw new ArgumentNullException("s");
 
-			byte[] pb;
 			using(MemoryStream ms = new MemoryStream())
 			{
-				MemUtil.CopyStream(s, ms);
-				pb = ms.ToArray();
+				CopyStream(s, ms);
+				return ms.ToArray();
 			}
-
-			return pb;
 		}
 
 		public static byte[] Read(Stream s, int nCount)
@@ -652,6 +671,17 @@ namespace KeePassLib.Utility
 			return pb;
 		}
 
+		internal static string ReadString(Stream s, Encoding enc)
+		{
+			if(s == null) throw new ArgumentNullException("s");
+			if(enc == null) throw new ArgumentNullException("enc");
+
+			using(StreamReader sr = new StreamReader(s, enc, true))
+			{
+				return sr.ReadToEnd();
+			}
+		}
+
 		public static void Write(Stream s, byte[] pbData)
 		{
 			if(s == null) { Debug.Assert(false); return; }
@@ -666,7 +696,6 @@ namespace KeePassLib.Utility
 			if(pbData == null) throw new ArgumentNullException("pbData");
 			if(pbData.Length == 0) return pbData;
 
-			byte[] pbCompressed;
 			using(MemoryStream msSource = new MemoryStream(pbData, false))
 			{
 				using(MemoryStream msCompressed = new MemoryStream())
@@ -674,14 +703,12 @@ namespace KeePassLib.Utility
 					using(GZipStream gz = new GZipStream(msCompressed,
 						CompressionMode.Compress))
 					{
-						MemUtil.CopyStream(msSource, gz);
+						CopyStream(msSource, gz);
 					}
 
-					pbCompressed = msCompressed.ToArray();
+					return msCompressed.ToArray();
 				}
 			}
-
-			return pbCompressed;
 		}
 
 		public static byte[] Decompress(byte[] pbCompressed)
@@ -689,7 +716,6 @@ namespace KeePassLib.Utility
 			if(pbCompressed == null) throw new ArgumentNullException("pbCompressed");
 			if(pbCompressed.Length == 0) return pbCompressed;
 
-			byte[] pbData;
 			using(MemoryStream msData = new MemoryStream())
 			{
 				using(MemoryStream msCompressed = new MemoryStream(pbCompressed, false))
@@ -697,14 +723,12 @@ namespace KeePassLib.Utility
 					using(GZipStream gz = new GZipStream(msCompressed,
 						CompressionMode.Decompress))
 					{
-						MemUtil.CopyStream(gz, msData);
+						CopyStream(gz, msData);
 					}
 				}
 
-				pbData = msData.ToArray();
+				return msData.ToArray();
 			}
-
-			return pbData;
 		}
 
 		public static int IndexOf<T>(T[] vHaystack, T[] vNeedle)
@@ -816,6 +840,43 @@ namespace KeePassLib.Utility
 			yield break;
 		}
 
+		internal static IEnumerable<T> Distinct<T, TKey>(IEnumerable<T> s,
+			GFunc<T, TKey> fGetKey, bool bPreferLast)
+		{
+			if(s == null) throw new ArgumentNullException("s");
+			if(fGetKey == null) throw new ArgumentNullException("fGetKey");
+
+			Dictionary<TKey, bool> d = new Dictionary<TKey, bool>();
+
+			if(bPreferLast)
+			{
+				List<T> l = new List<T>(s);
+				int n = l.Count;
+				bool[] v = new bool[n];
+
+				for(int i = n - 1; i >= 0; --i)
+				{
+					TKey k = fGetKey(l[i]);
+					if(!d.ContainsKey(k)) { d[k] = true; v[i] = true; }
+				}
+
+				for(int i = 0; i < n; ++i)
+				{
+					if(v[i]) yield return l[i];
+				}
+			}
+			else
+			{
+				foreach(T t in s)
+				{
+					TKey k = fGetKey(t);
+					if(!d.ContainsKey(k)) { d[k] = true; yield return t; }
+				}
+			}
+
+			yield break;
+		}
+
 		internal static bool ListsEqual<T>(List<T> a, List<T> b)
 			where T : class, IEquatable<T>
 		{
@@ -862,6 +923,33 @@ namespace KeePassLib.Utility
 			if(d != null) d.Dispose();
 		}
 
+		internal static object GetEnumValue(Type tEnum, string strName)
+		{
+			if(tEnum == null) { Debug.Assert(false); return null; }
+			if(!tEnum.IsEnum) { Debug.Assert(false); return null; }
+			if(string.IsNullOrEmpty(strName)) { Debug.Assert(false); return null; }
+
+			return ((Array.IndexOf<string>(Enum.GetNames(tEnum), strName) >= 0) ?
+				Enum.Parse(tEnum, strName) : null);
+		}
+
+		internal static T ConvertObject<T>(object o, T tDefault)
+		{
+			if(o == null) return tDefault;
+
+			try
+			{
+				if(o is T) return (T)o;
+				return (T)Convert.ChangeType(o, typeof(T));
+			}
+			catch(Exception) { Debug.Assert(false); }
+
+			try { return (T)o; }
+			catch(Exception) { Debug.Assert(false); }
+
+			return tDefault;
+		}
+
 		internal static T BytesToStruct<T>(byte[] pb, int iOffset)
 			where T : struct
 		{
